<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Ilmaisimen tyyli</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Alavalikko</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klassinen</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Asema</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Näytä aina</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Piilotta paneeli</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Älykäs piilotus</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Telakan asetukset</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>